from django.conf import settings
from django.core.urlresolvers import reverse

from .templating import (
    list_templates,
    render_template,
    )


def get_header_info(user):
    info = dict()
    if user.is_authenticated:
        info['personal_url'] = reverse('person_view', args=(user.username,))
    info['index_url'] = reverse('index')
    info['help_url'] = reverse('help')
    info['static_prefix'] = settings.STATIC_URL
    info['combo_url'] = settings.COMBO_URL
    info['debug'] = settings.DEBUG
    return info


def render_page(title, heading, content, user, extra_scripts=None):
    info = get_header_info(user)
    info['title'] = title
    info['heading'] = heading
    info['content'] = content
    info['templates'] = list_templates()
    if extra_scripts:
        def make_combo_path(path):
            return u"i/" + path
        info['extra_scripts'] = u'<script src="%s?%s" type="text/javascript"></script>' % (
                settings.COMBO_URL, u"&".join(map(make_combo_path, extra_scripts)))
    return render_template('base.html', info)
