import codecs
import json
import os

from django.conf import settings
import pybars


_compiler = None
def get_compiler():
    global _compiler
    if _compiler is None:
        _compiler = pybars.Compiler()
    return _compiler


_template_loader_cache = dict()
def load_template(name):
    global _template_loader_cache
    if name not in _template_loader_cache or settings.DEBUG:
        template_path = os.path.join(os.path.dirname(__file__),
                'templates', name)
        with codecs.open(template_path, 'r', 'utf-8') as f:
            content = f.read()
        _template_loader_cache[name] = content
    return _template_loader_cache[name]


_template_compiler_cache = dict()
def compile_template(name):
    global _template_compiler_cache
    if name not in _template_compiler_cache or settings.DEBUG:
        source = load_template(name)
        compiler = get_compiler()
        template = compiler.compile(source)
        _template_compiler_cache[name] = template
    return _template_compiler_cache[name]


def compile_template_from_string(name, source):
    global _template_compiler_cache
    if name not in _template_compiler_cache or settings.DEBUG:
        compiler = get_compiler()
        template = compiler.compile(source)
        _template_compiler_cache[name] = template
    return _template_compiler_cache[name]


def render_template(name, info, partials=None, helpers=None):
    template = compile_template(name)
    return template(info, partials=partials, helpers=helpers)


def list_templates():
    return [
        dict(name='deployment_request', content=load_template('revtracker/deployment_request.html')),
        dict(name='index', content=load_template('revtracker/index.html')),
        dict(name='project', content=load_template('revtracker/project.html')),
        dict(name='project_info', content=load_template('revtracker/project_info.html')),
        dict(name='revision_comment_form', content=load_template('revtracker/revision_comment_form.html')),
        dict(name='revision_info', content=load_template('revtracker/revision_info.html')),
        dict(name='revision_form', content=load_template('revtracker/revision_form.html')),
        dict(name='deployability_form', content=load_template('revtracker/deployability_form.html')),
        ]


_partials_cache = None
def get_partials():
    global _partials_cache
    if _partials_cache is None or settings.DEBUG:
        templates = list_templates()
        partials = dict()
        for template in templates:
            partials[template['name']] = compile_template_from_string(
                    template['name'], template['content'])
        _partials_cache = partials
    return _partials_cache


def dump_json_helper(this, thing):
    while not getattr(thing, 'keys', None):
        thing = thing.context
    return json.dumps(thing)


def ignore_content(this, options):
    return options['inverse'](this)


def include_content(this, options):
    return options['fn'](this)
